Module process

Module process 

Functions

clone_child
clone_child creates a child process that invokes function in seperated Linux namespaces specified in namespace_list. For more information, see the clone(2) man page.
inspect_process
inspect_process inspects the status of the process in /proc/<pid>/stat and returns a variant of the ProcState enum that represents the process status.